# ImageAnalyst ONNX

ImageAnalyst ONNX is an extension to the [ImageAnalyst](https://github.com/BergLucas/ImageAnalyst) library, providing additional models and functions using [onnx](https://pypi.org/project/onnxruntime/).

## Requirements

The application requires:

- [Python](https://www.python.org/) ~= 3.9
- [pip](https://pip.pypa.io/en/stable/)

## Download & Installation

There is two ways to download and install the application.

### Using PyPI

You can download and install the application using [PyPI](https://pypi.org/project/image-analyst-onnx/). To do so, run the following command:

```bash
pip install image-analyst-onnx
```

### Using the GitHub releases

You can download the application on the [downloads page](https://github.com/BergLucas/ImageAnalystONNX/releases). Then, you can install the application by running the following command:

```bash
pip install image_analyst_onnx-X.X.X-py3-none-any.whl
```

(Note: The X.X.X must be replaced by the version that you want to install.)

## License

All code is licensed for others under a MIT license (see [LICENSE](https://github.com/BergLucas/ImageAnalystONNX/blob/main/LICENSE)).
